Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1759)

Unified Diff: third_party/WebKit/public/web/WebRemoteFrame.h

Issue 2046733003: Replicate WebInsecureRequestPolicy instead of a bool for strict mixed content checks. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@securitycontext
Patch Set: alexmos@ Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/public/web/WebFrameClient.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebRemoteFrame.h
diff --git a/third_party/WebKit/public/web/WebRemoteFrame.h b/third_party/WebKit/public/web/WebRemoteFrame.h
index 58283079812ffd3ab978f96ad68986bb76007d56..37ca0a305b9a400cc88fe6cbc1008e481e4aec02 100644
--- a/third_party/WebKit/public/web/WebRemoteFrame.h
+++ b/third_party/WebKit/public/web/WebRemoteFrame.h
@@ -5,6 +5,7 @@
#ifndef WebRemoteFrame_h
#define WebRemoteFrame_h
+#include "public/platform/WebInsecureRequestPolicy.h"
#include "public/web/WebContentSecurityPolicy.h"
#include "public/web/WebFrame.h"
#include "public/web/WebSandboxFlags.h"
@@ -47,8 +48,8 @@ public:
// Resets replicated CSP headers to an empty set.
virtual void resetReplicatedContentSecurityPolicy() const = 0;
- // Set frame enforcement of strict mixed content checking replicated from another process.
- virtual void setReplicatedShouldEnforceStrictMixedContentChecking(bool) const = 0;
+ // Set frame enforcement of insecure request policy replicated from another process.
+ virtual void setReplicatedInsecureRequestPolicy(WebInsecureRequestPolicy) const = 0;
// Set the frame to a unique origin that is potentially trustworthy,
// replicated from another process.
« no previous file with comments | « third_party/WebKit/public/web/WebFrameClient.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698